@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Deployment;
-$Footprintless::Deployment::VERSION = '1.05';
+$Footprintless::Deployment::VERSION = '1.06';
 # ABSTRACT: A deployment manager
 # PODNAME: Footprintless::Deployment
 
@@ -39,11 +39,13 @@ sub deploy {
 
     if ( $options{to_dir} ) {
         $self->_deploy( $options{to_dir} );
+        &{ $options{extra} }( $options{to_dir} ) if ( $options{extra} );
     }
     else {
         $self->_local_template(
             sub {
                 $self->_deploy(@_);
+                &{ $options{extra} }(@_) if ( $options{extra} );
             },
             rebase => $options{rebase}
         );
@@ -106,7 +108,7 @@ Footprintless::Deployment - A deployment manager
 
 =head1 VERSION
 
-version 1.05
+version 1.06
 
 =head1 SYNOPSIS
 
@@ -206,6 +208,13 @@ are:
 
 =over 4
 
+=item extra 
+
+A subroutine that is called during deployment allowing you to add to
+what is deployed before it is pushed to its destination.  This subroutine
+will be called with a single argument containing the (possibly temporary)
+directory that you can write additional files to.
+
 =item names
 
 A list of names of resources that should be deployed.  If this option is
