@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Factory;
-$Footprintless::Factory::VERSION = '1.05';
+$Footprintless::Factory::VERSION = '1.06';
 # ABSTRACT: The default factory for footprintless modules
 # PODNAME: Footprintless::Factory
 
@@ -18,10 +18,10 @@ sub new {
 }
 
 sub agent {
-    my ($self) = @_;
+    my ( $self, %options ) = @_;
 
     unless ( $self->{agent} ) {
-        $self->{agent} = Footprintless::Util::agent();
+        $self->{agent} = Footprintless::Util::agent(%options);
     }
 
     return $self->{agent};
@@ -174,7 +174,7 @@ Footprintless::Factory - The default factory for footprintless modules
 
 =head1 VERSION
 
-version 1.05
+version 1.06
 
 =head1 DESCRIPTION
 
