@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Util;
-$Footprintless::Util::VERSION = '1.05';
+$Footprintless::Util::VERSION = '1.06';
 # ABSTRACT: A utility method package for common functionality in Footprintless
 # PODNAME: Footprintless::Util
 
@@ -31,9 +31,14 @@ our @EXPORT_OK = qw(
 my $logger = Log::Any->get_logger();
 
 sub agent {
+    my (%options) = @_;
     require LWP::UserAgent;
     my $agent = LWP::UserAgent->new();
     $agent->env_proxy();
+
+    $agent->timeout( $options{timeout} )       if ( defined( $options{timeout} ) );
+    $agent->cookie_jar( $options{cookie_jar} ) if ( defined( $options{cookie_jar} ) );
+
     return $agent;
 }
 
@@ -56,7 +61,10 @@ sub clean {
             $command_runner->run_or_die(
                 Footprintless::Command::batch_command(
                     Footprintless::Command::rm_command(@all_paths),
-                    Footprintless::Command::mkdir_command(@dir_paths),
+                    (   @dir_paths
+                        ? Footprintless::Command::mkdir_command(@dir_paths)
+                        : ()
+                    ),
                     $options{command_options}
                 )
             );
@@ -239,7 +247,7 @@ Footprintless::Util - A utility method package for common functionality in Footp
 
 =head1 VERSION
 
-version 1.05
+version 1.06
 
 =head1 SYNOPSIS
 
